class Options:

    def __init__(self, show_saved=False, save_different=False, save_main_arg_exists=False, custom_save=False):
        self.show_saved = show_saved
        self.save_different = save_different
        self.save_main_arg_exists = save_main_arg_exists
        self.custom_save = custom_save

